//Source file: PolicyActionType.java
//Date: September 2004
//Policy Management Data Types for 3GPP TS 29.198-13 V5.6.0

package org.csapi.jr.se.policy;

/**
 * This data type defines the action type in a policy rule.
 *
 */
public final class PolicyActionType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static PolicyActionType[] _array = new PolicyActionType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PolicyActionType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * IpPolicyEventAction
     */
    public static final int _PM_EVENT_ACTION =  0;

    /**
     * IpPolicyEventAction
     */
    public static final PolicyActionType PM_EVENT_ACTION = new PolicyActionType(_PM_EVENT_ACTION);

    /**
     * IpPolicyExpressionAction
     */
    public static final int _PM_EXPRESSION_ACTION =  1;

    /**
     * IpPolicyExpressionAction
     */
    public static final PolicyActionType PM_EXPRESSION_ACTION = new PolicyActionType(_PM_EXPRESSION_ACTION);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved PolicyActionType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PolicyActionType object
     */
    public String getValueText() {
        switch (_value) {
            case _PM_EVENT_ACTION:
                return "PM_EVENT_ACTION";
            case _PM_EXPRESSION_ACTION:
                return "PM_EXPRESSION_ACTION";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PolicyActionType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PolicyActionType)) {
            return false;
        }
        PolicyActionType policyActionType = (PolicyActionType) o; 
        if(!(this.getValue() == policyActionType.getValue())) {
            return false;
        }
        if (this.hashCode() != policyActionType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PolicyActionType

