//Source file: PolicyConditionListType.java
//Date: September 2004
//Policy Management Data Types for 3GPP TS 29.198-13 V5.6.0

package org.csapi.jr.se.policy;

/**
 * This data type defines the type condition list in a policy rule.
 *
 */
public final class PolicyConditionListType implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static PolicyConditionListType[] _array = new PolicyConditionListType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PolicyConditionListType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Disjunctive normal form
     */
    public static final int _PM_DNF =  0;

    /**
     * Disjunctive normal form
     */
    public static final PolicyConditionListType PM_DNF = new PolicyConditionListType(_PM_DNF);

    /**
     * Conjunctive normal form
     */
    public static final int _PM_CNF =  1;

    /**
     * Conjunctive normal form
     */
    public static final PolicyConditionListType PM_CNF = new PolicyConditionListType(_PM_CNF);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved PolicyConditionListType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PolicyConditionListType object
     */
    public String getValueText() {
        switch (_value) {
            case _PM_DNF:
                return "PM_DNF";
            case _PM_CNF:
                return "PM_CNF";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PolicyConditionListType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PolicyConditionListType)) {
            return false;
        }
        PolicyConditionListType policyConditionListType = (PolicyConditionListType) o; 
        if(!(this.getValue() == policyConditionListType.getValue())) {
            return false;
        }
        if (this.hashCode() != policyConditionListType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PolicyConditionListType

