//Source file: PolicyConditionType.java
//Date: September 2004
//Policy Management Data Types for 3GPP TS 29.198-13 V5.6.0

package org.csapi.jr.se.policy;

/**
 * This data type defines the condition type in a policy rule.
 *
 */
public final class PolicyConditionType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static PolicyConditionType[] _array = new PolicyConditionType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private PolicyConditionType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * IpPolicyTimePeriodCondition
     */
    public static final int _PM_TIME_PERIOD_CONDITION =  0;

    /**
     * IpPolicyTimePeriodCondition
     */
    public static final PolicyConditionType PM_TIME_PERIOD_CONDITION = new PolicyConditionType(_PM_TIME_PERIOD_CONDITION);

    /**
     * IpPolicyEventCondition
     */
    public static final int _PM_EVENT_CONDITION =  1;

    /**
     * IpPolicyEventCondition
     */
    public static final PolicyConditionType PM_EVENT_CONDITION = new PolicyConditionType(_PM_EVENT_CONDITION);

    /**
     * IpPolicyExpressionCondition
     */
    public static final int _PM_EXPRESSION_CONDITION =  2;

    /**
     * IpPolicyExpressionCondition
     */
    public static final PolicyConditionType PM_EXPRESSION_CONDITION = new PolicyConditionType(_PM_EXPRESSION_CONDITION);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved PolicyConditionType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the PolicyConditionType object
     */
    public String getValueText() {
        switch (_value) {
            case _PM_TIME_PERIOD_CONDITION:
                return "PM_TIME_PERIOD_CONDITION";
            case _PM_EVENT_CONDITION:
                return "PM_EVENT_CONDITION";
            case _PM_EXPRESSION_CONDITION:
                return "PM_EXPRESSION_CONDITION";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static PolicyConditionType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PolicyConditionType)) {
            return false;
        }
        PolicyConditionType policyConditionType = (PolicyConditionType) o; 
        if(!(this.getValue() == policyConditionType.getValue())) {
            return false;
        }
        if (this.hashCode() != policyConditionType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PolicyConditionType

