//Source file: PolicyDomain.java
//Date: September 2004
//Policy Management Interfaces for 3GPP TS 29.198-13 V5.6.0

package org.csapi.jr.se.policy;

/**
 * This interface represents a PolicyDomain.<BR>
 *
 */
public interface PolicyDomain extends org.csapi.jr.se.Service {

    /**
     * Adds a PolicyDomainListener which is interested in events generated by the PolicyDomain.
     *
     * @param  policyDomainListener  A reference to the PolicyDomainListener which is to be added as
     *         a listener.
     */
    void addPolicyDomainListener(org.csapi.jr.se.policy.PolicyDomainListener policyDomainListener);

    /**
     * Removes a PolicyDomainListener which is no longer interested in events generated by the PolicyDomain.
     *
     * @param  policyDomainListener  A reference to the PolicyDomainListener which is to be removed as
     *         a listener.
     */
    void removePolicyDomainListener(org.csapi.jr.se.policy.PolicyDomainListener policyDomainListener);

    /**
     * Invokes the getParentDomain() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyDomain getParentDomain()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the createDomain() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyDomain createDomain(
           java.lang.String                domainName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getDomain() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyDomain getDomain(
           java.lang.String                domainName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Invokes the removeDomain() method on the Parlay Gateway.
     */
    void removeDomain(
           java.lang.String                domainName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getDomainCount() method on the Parlay Gateway.
     */
    int getDomainCount()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the getDomainIterator() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyIterator getDomainIterator()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the createGroup() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyGroup createGroup(
           java.lang.String                groupName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getGroup() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyGroup getGroup(
           java.lang.String                groupName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Invokes the removeGroup() method on the Parlay Gateway.
     */
    void removeGroup(
           java.lang.String                groupName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getGroupCount() method on the Parlay Gateway.
     */
    int getGroupCount()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the getGroupIterator() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyIterator getGroupIterator()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the createRule() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyRule createRule(
           java.lang.String                ruleName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getRule() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyRule getRule(
           java.lang.String                ruleName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Invokes the removeRule() method on the Parlay Gateway.
     */
    void removeRule(
           java.lang.String                ruleName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getRuleCount() method on the Parlay Gateway.
     */
    int getRuleCount()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the getRuleIterator() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyIterator getRuleIterator()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the createEventDefinition() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyEventDefinition createEventDefinition(
           java.lang.String                eventDefinitionName,
           java.lang.String[]              requiredAttributes,
           java.lang.String[]              optionalAttributes)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getEventDefinition() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyEventDefinition getEventDefinition(
           java.lang.String                eventDefinitionName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Invokes the removeEventDefinition() method on the Parlay Gateway.
     */
    void removeEventDefinition(
           java.lang.String                eventDefinitionName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getEventDefinitionCount() method on the Parlay Gateway.
     */
    int getEventDefinitionCount()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the getEventDefinitionIterator() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyIterator getEventDefinitionIterator()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the generateEvent() method on the Parlay Gateway.
     */
    void generateEvent(
           java.lang.String                eventDefinitionName,
           org.csapi.jr.se.Attribute[] attributes)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Invokes the createVariableSet() method on the Parlay Gateway.
     */
    void createVariableSet(
           java.lang.String                variableSetName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getVariableSet() method on the Parlay Gateway.
     */
    org.csapi.jr.se.Attribute[] getVariableSet(
           java.lang.String                variableSetName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Invokes the removeVariableSet() method on the Parlay Gateway.
     */
    void removeVariableSet(
           java.lang.String                variableSetName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getVariableSetCount() method on the Parlay Gateway.
     */
    int getVariableSetCount()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the getVariableSetIterator() method on the Parlay Gateway.
     */
    org.csapi.jr.se.policy.PolicyIterator getVariableSetIterator()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException;

    /**
     * Invokes the setVariable() method on the Parlay Gateway.
     */
    void setVariable(
           java.lang.String                variableSetName,
           org.csapi.jr.se.Attribute variable)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException,
       org.csapi.jr.se.policy.NoTransactionInProcessException;

    /**
     * Invokes the getVariable() method on the Parlay Gateway.
     */
    org.csapi.jr.se.Attribute getVariable(
           java.lang.String                variableSetName,
           java.lang.String                variableName)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.policy.AccessViolationException,
       org.csapi.jr.se.policy.SyntaxErrorException,
       org.csapi.jr.se.policy.NameSpaceErrorException;

    /**
     * Creates a Notification object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notification interface.
     */
    org.csapi.jr.se.policy.Notification createNotification();

}
