//Source file: PolicyEvent.java
//Date: September 2004
//Policy Management Data Types for 3GPP TS 29.198-13 V5.6.0

package org.csapi.jr.se.policy;

/**
 * This data type is a Sequence of Data Elements which describes a generic 'event'.  Events can be generated in response to network activity, as a result of clients calling the generateEvent() method of IpPolicyDomain, or as a result of the evaluation of an IpPolicyEventAction action. Each instance of a generated event is identified by a unique EventID, a 32-bit integer. The time the event was generated is captured in the attribute TimeGenerated. All of the attributes in the RequiredAttributes list of the EventDefinition associated with the given EventDefinitionName must be present in Attributes. Any other attributes must be in the OptionalAttributes list of the same EventDefinition.
 * 
 */
public final class PolicyEvent implements java.io.Serializable {

    private int eventID;
    private String timeGenerated;
    private org.csapi.jr.se.Attribute[] attributes;
    private String eventDefinitionName;
    private String eventDomainName;

    /**
     * Creates a new PolicyEvent instance.
     */
    public PolicyEvent () {}

    /**
     * Creates a new PolicyEvent instance.
     * @param _eventID   
     * @param _timeGenerated   
     * @param _attributes   
     * @param _eventDefinitionName   
     * @param _eventDomainName   
     */
    public PolicyEvent (int _eventID, String _timeGenerated, org.csapi.jr.se.Attribute[] _attributes, String _eventDefinitionName, String _eventDomainName) {

        this.eventID = _eventID;
        this.timeGenerated = _timeGenerated;
        this.attributes = _attributes;
        this.eventDefinitionName = _eventDefinitionName;
        this.eventDomainName = _eventDomainName;
    }

    /**
     * This method returns a eventID.
     * 
     * @return a int value
     */
    public int getEventID() {
        return eventID;
    }

    /**
     * This method returns a timeGenerated.
     * 
     * @return a String value
     */
    public String getTimeGenerated() {
        return timeGenerated;
    }

    /**
     * This method returns a attributes.
     * 
     * @return a org.csapi.jr.se.Attribute[] value
     */
    public org.csapi.jr.se.Attribute[] getAttributes() {
        return attributes;
    }

    /**
     * This method returns a eventDefinitionName.
     * 
     * @return a String value
     */
    public String getEventDefinitionName() {
        return eventDefinitionName;
    }

    /**
     * This method returns a eventDomainName.
     * 
     * @return a String value
     */
    public String getEventDomainName() {
        return eventDomainName;
    }


    /**
     * This method sets a eventID.
     */ 
    public void setEventID(int eventID) {
        this.eventID = eventID;
    }

    /**
     * This method sets a timeGenerated.
     */ 
    public void setTimeGenerated(String timeGenerated) {
        this.timeGenerated = timeGenerated;
    }

    /**
     * This method sets a attributes.
     */ 
    public void setAttributes(org.csapi.jr.se.Attribute[] attributes) {
        this.attributes = attributes;
    }

    /**
     * This method sets a eventDefinitionName.
     */ 
    public void setEventDefinitionName(String eventDefinitionName) {
        this.eventDefinitionName = eventDefinitionName;
    }

    /**
     * This method sets a eventDomainName.
     */ 
    public void setEventDomainName(String eventDomainName) {
        this.eventDomainName = eventDomainName;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof PolicyEvent)) {
            return false;
        } 
        PolicyEvent policyEvent = (PolicyEvent) o;
        if(!(this.eventID == policyEvent.eventID)) {
            return false;
        }
        if(!(this.timeGenerated == policyEvent.timeGenerated))  {
            return false;
        }
        if ((this.eventDefinitionName != null) && (policyEvent.eventDefinitionName != null)) {
            if(!(this.eventDefinitionName.equals(policyEvent.eventDefinitionName)))  {
                return false;
            }
        }
        if ((this.eventDomainName != null) && (policyEvent.eventDomainName != null)) {
            if(!(this.eventDomainName.equals(policyEvent.eventDomainName)))  {
                return false;
            }
        }
        if(!(this.attributes == policyEvent.attributes))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // PolicyEvent

